force fDaemon in bitcoind
authortcatm <tcatm@gawab.com>
Thu, 3 Mar 2011 21:31:44 +0000 (22:31 +0100)
committertcatm <tcatm@gawab.com>
Thu, 3 Mar 2011 21:31:44 +0000 (22:31 +0100)
init.cpp

index 0548acc..f3ec28b 100644 (file)
--- a/init.cpp
+++ b/init.cpp
@@ -199,9 +199,10 @@ bool AppInit2(int argc, char* argv[])
     else
         fServer = GetBoolArg("-server");
 
/* force fServer when running without GUI */
 #ifndef GUI
     fServer = true;
+    fDaemon = true;
 #endif
 
     fPrintToConsole = GetBoolArg("-printtoconsole");
@@ -199,9 +199,10 @@ bool AppInit2(int argc, char* argv[])
         fServer = GetBoolArg("-server");
 
-    /* force fServer when running without GUI */
+    /* force fServer and fDaemon when running without GUI */
 #ifndef GUI
     fServer = true;